<?php
/**
 * This file represents an example of the code that themes would use to register
 * the required plugins.
 *
 * It is expected that theme authors would copy and paste this code into their
 * functions.php file, and amend to suit.
 *
 * @package    TGM-Plugin-Activation
 * @subpackage Example
 * @version    2.4.0
 * @author     Thomas Griffin <thomasgriffinmedia.com>
 * @author     Gary Jones <gamajo.com>
 * @copyright  Copyright (c) 2014, Thomas Griffin
 * @license    http://opensource.org/licenses/gpl-2.0.php GPL v2 or later
 * @link       https://github.com/thomasgriffin/TGM-Plugin-Activation
 */

/**
 * Include the TGM_Plugin_Activation class.
 */
require_once get_template_directory() . '/inc/tgm-plugin-activation/class-tgm-plugin-activation.php';

add_action( 'tgmpa_register', 'laundryes_register_required_plugins' );
/**
 * Register the required plugins for this theme.
 *
 * In this example, we register two plugins - one included with the TGMPA library
 * and one from the .org repo.
 *
 * The variable passed to tgmpa_register_plugins() should be an array of plugin
 * arrays.
 *
 * This function is hooked into tgmpa_init, which is fired within the
 * TGM_Plugin_Activation class constructor.
 */
function laundryes_register_required_plugins() {

    $plugins  = array(
		array(
			'name'     				=> 'Revolation Slider',
			'slug'     				=> 'revslider',
			'source'				  => 'http://metheme.biz/plugins/common/revslider.zip',
			'required' 				=> true,
			
		),
		array(
			'name'     				=> 'WPBakery Visual Composer',
			'slug'     				=> 'js_composer',
			'source'   				  => 'http://metheme.biz/plugins/common/js_composer.zip',
			'required' 				=> true,
			
		),
		array(
			'name'     				=> 'Laundryes Core',
			'slug'     				=> 'laundryes_core',
			'source'   				  =>  'http://metheme.biz/plugins/laundryes/laundryes_core.zip',
			'required' 				=> true,
			
			
		),
		array(
			'name'     				=> 'Contact Form 7',
			'slug'     				=> 'contact-form-7',
			'required' 				=> true,
		),
		array(
			'name'     				=> 'Email Subscribers',
			'slug'     				=> 'email-subscribers',
			'required' 				=> true,
		),
		array(
	            'name'      		=> 'Redux Framework',
	            'slug'     		 	=> 'redux-framework',
	            'required'  		=> true,
        ),
        array(
	            'name'      		=> 'Advanced Custom Fields',
	            'slug'     		 	=> 'advanced-custom-fields',
	            'required'  		=> true,
        ),
		

	);

	 $config = array(
        'id'           => 'tgmpa-jk-1.8.2'          // Unique ID for hashing notices for multiple instances of TGMPA.
    );

    tgmpa( $plugins, $config );
}
